Music-Scrapper
==============

.. image:: https://badge.fury.io/py/music_scraper.svg
    :target: https://badge.fury.io/py/music_scraper
.. image:: https://landscape.io/github/srivatsan-ramesh/Music-Scraper/master/landscape.svg?style=flat
   :target: https://landscape.io/github/srivatsan-ramesh/Music-Scraper/master
   :alt: Code Health\\
   
Download all your favourite songs from the web at one place. No more searching through the links given by Google Search, Music-Scraper does it for you.

Requirements
------------

-   python>=2.7
-   Scrapy>=1.1.1

Getting Started
---------------

Ensure that you have setuptools>=24.0.3 installed for proper installation of music_scraper.
Installation of setuptools can be done with

.. code-block:: bash

    pip install setuptools==24.0.3

Install Music-Scraper from pip directly

.. code-block:: bash

    pip install music_scraper

Or

Clone this repository to get started.

.. code-block:: bash

    git clone https://github.com/srivatsan-ramesh/Music-Scraper.git
    cd Music-Scraper/

And install it.

.. code-block:: bash

    python setup.py install

You can also install it for development.

.. code-block:: bash

    python setup.py develop

If Scrapy installation creates some problem refer this `link <http://doc.scrapy.org/en/latest/intro/install.html>`_.

How to Use
----------

Type 'music-scraper' in the terminal and type in a query which can give audio files in Google Search. For example 'kabali songs download'.
